==> entitybean-container-5.0-sources.jar: org/glassfish/persistence/ejb/entitybean/container/ReadOnlyContextImpl.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2017 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package org.glassfish.persistence.ejb.entitybean.container;

import javax.ejb.EnterpriseBean;
import com.sun.ejb.containers.BaseContainer;

/**
 * Implementation of EJBContext for ReadOnlyBeans. Contains extra
 * attributes that allows selective ejbLoad()
 *
 * @author Mahesh Kannan
 */

public final class ReadOnlyContextImpl
    extends EntityContextImpl
{
    private int pkLevelSequenceNum;
    private long lastRefreshedAt;   
    private boolean removed = false;

    // only non-null when associated with a primary-key
    transient private ReadOnlyBeanInfo robInfo;
    
    ReadOnlyContextImpl(EnterpriseBean ejb, BaseContainer container) {
        super(ejb, container);
    }

    public int getPKLevelSequenceNum() {
        return pkLevelSequenceNum;
    }

    public void incrementPKLevelSequenceNum() {
        pkLevelSequenceNum++;
    }

    public void setPKLevelSequenceNum(int num) {
        pkLevelSequenceNum = num;
    }

    public long getLastRefreshedAt() {
        return lastRefreshedAt;
    }
    
    public void setLastRefreshedAt(long time) {
        lastRefreshedAt = time;
    }
    
    public boolean isRemoved() {
        return removed;
    }
    
    public void setRemoved(boolean value) {
        removed = value;
    }
    
    public void setReadOnlyBeanInfo(ReadOnlyBeanInfo info) {
        robInfo = info;

        // Whenever read-only bean info is set or nulled out, initialize
        // its derived fields.
        pkLevelSequenceNum = -1;
        lastRefreshedAt = 0;
    }

    public ReadOnlyBeanInfo getReadOnlyBeanInfo() {
        return robInfo;
    }
}

==> entitybean-container-7.0.5-sources.jar: org/glassfish/persistence/ejb/entitybean/container/ReadOnlyContextImpl.java <==
/*
 * Copyright (c) 1997, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.glassfish.persistence.ejb.entitybean.container;

import jakarta.ejb.EnterpriseBean;
import com.sun.ejb.containers.BaseContainer;

/**
 * Implementation of EJBContext for ReadOnlyBeans. Contains extra
 * attributes that allows selective ejbLoad()
 *
 * @author Mahesh Kannan
 */

public final class ReadOnlyContextImpl
    extends EntityContextImpl
{
    private int pkLevelSequenceNum;
    private long lastRefreshedAt;
    private boolean removed = false;

    // only non-null when associated with a primary-key
    transient private ReadOnlyBeanInfo robInfo;

    ReadOnlyContextImpl(EnterpriseBean ejb, BaseContainer container) {
        super(ejb, container);
    }

    public int getPKLevelSequenceNum() {
        return pkLevelSequenceNum;
    }

    public void incrementPKLevelSequenceNum() {
        pkLevelSequenceNum++;
    }

    public void setPKLevelSequenceNum(int num) {
        pkLevelSequenceNum = num;
    }

    public long getLastRefreshedAt() {
        return lastRefreshedAt;
    }

    public void setLastRefreshedAt(long time) {
        lastRefreshedAt = time;
    }

    public boolean isRemoved() {
        return removed;
    }

    public void setRemoved(boolean value) {
        removed = value;
    }

    public void setReadOnlyBeanInfo(ReadOnlyBeanInfo info) {
        robInfo = info;

        // Whenever read-only bean info is set or nulled out, initialize
        // its derived fields.
        pkLevelSequenceNum = -1;
        lastRefreshedAt = 0;
    }

    public ReadOnlyBeanInfo getReadOnlyBeanInfo() {
        return robInfo;
    }
}
